@@ -12,6 +12,7 @@ from ...models.company.assets.ai_agents_v2.ai_agents_decision_output import Inco
 class SmartTaggingCallbackMetadata(BaseModel):
     chat_id: StrObjectId
     company_id: StrObjectId
+    trigger: ChainOfThoughtInChatTrigger
 
 class ComparisonAnalysisCallbackMetadata(BaseModel):
     test_case_id: StrObjectId
@@ -23,6 +24,7 @@ class InteractionCallbackMetadata(BaseModel):
     ai_agent_id: StrObjectId
     company_id: StrObjectId
     interaction_index: int
+    trigger: ChainOfThoughtInChatTrigger
 
 class QualityTestCallbackEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.SINGLE_QUALITY_TEST_CALLBACK
@@ -109,7 +111,7 @@ class DoubleCheckerCallbackMetadata(BaseModel):
     ai_agent_id: StrObjectId
     incoming_messages_ids: List[str]
     # Trigger info
-    trigger: str
+    trigger: ChainOfThoughtInChatTrigger
     # Trigger info is in: incoming_messages_ids for user_message,
     # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
     triggered_by_user_id: Optional[StrObjectId] = None
@@ -118,16 +120,17 @@ class DoubleCheckerForIncomingMessagesAnswerEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER
     data: DoubleCheckerForIncomingMessagesAnswerData
 
-class DoubleCheckerForIncomingMessagesAnswerCallbackEvent(LambdaAiEvent):
-    type: InvokationType = InvokationType.DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER_CALLBACK
-    data: DoubleCheckerForIncomingMessagesAnswerData
-    callback_metadata: DoubleCheckerCallbackMetadata
-
 class DoubleCheckerForIncomingMessagesAnswerCallbackMetadata(BaseModel):
     chat_id: StrObjectId
     company_id: StrObjectId
     ai_agent_id: StrObjectId
 
+class DoubleCheckerForIncomingMessagesAnswerCallbackEvent(LambdaAiEvent):
+    type: InvokationType = InvokationType.DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER_CALLBACK
+    data: ExpectedOutputIncomingMessage
+    callback_metadata: DoubleCheckerForIncomingMessagesAnswerCallbackMetadata
+
+
 
 # Smart Follow-Up Decision Output Events
 
