@@ -32,11 +32,33 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         self.collection: Collection = connection.client[database][collection]
 
         # NEW: Async database and collection
-        self.async_db: AsyncIOMotorDatabase = connection.async_client[database]
-        self.async_collection: AsyncIOMotorCollection = connection.async_client[database][collection]
+        # Store connection reference to ensure we use current event loop
+        self._connection = connection
+        self._database_name = database
+        self._collection_name = collection
+        self._async_db: Optional[AsyncIOMotorDatabase] = None
+        self._async_collection: Optional[AsyncIOMotorCollection] = None
 
         self.type = type
         self.preview_type = preview_type
+
+    @property
+    def async_db(self) -> AsyncIOMotorDatabase:
+        """Get async database, ensuring it uses the current event loop"""
+        # Always ensure connection's async client is using current loop (for Lambda compatibility)
+        self._connection._ensure_async_client_loop()
+        # Recreate database reference to ensure it uses the current client
+        self._async_db = self._connection.async_client[self._database_name]
+        return self._async_db
+
+    @property
+    def async_collection(self) -> AsyncIOMotorCollection:
+        """Get async collection, ensuring it uses the current event loop"""
+        # Always ensure connection's async client is using current loop (for Lambda compatibility)
+        self._connection._ensure_async_client_loop()
+        # Recreate collection reference to ensure it uses the current client
+        self._async_collection = self._connection.async_client[self._database_name][self._collection_name]
+        return self._async_collection
     @abstractmethod
     def create_instance(self, data: dict) -> T:
         """Factory method to create instance from data"""
