@@ -20,7 +20,6 @@ from datetime import datetime
 from typing import Dict, Any, Optional, List, TYPE_CHECKING
 from letschatty.models.execution.execution import ExecutionContext
 from letschatty.models.messages.meta_message_model.meta_status_json import ErrorDetail
-from letschatty.services.continuous_conversation_service.continuous_conversation_helper import ContinuousConversationHelper
 from ...models.company.assets.product import Product
 from ...models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent
 from ...models.company.assets.ai_agents_v2.chatty_ai_mode import ChattyAIMode
@@ -425,6 +424,8 @@ class ChatService:
         """
         Update the status of a message in the chat.
         """
+        from letschatty.services.continuous_conversation_service.continuous_conversation_helper import ContinuousConversationHelper
+
         message = chat.get_message_by_id(message_id)
         if message is None:
             # logger.warning(f"Message with id {message_id} not found in chat {chat.id}")
@@ -658,7 +659,7 @@ class ChatService:
         if client_data.email is not None:
             chat.client.email = client_data.email
         if client_data.DNI is not None:
-            chat.client.DNI = client_data.DNI
+            chat.client.document_id = client_data.DNI
         if client_data.external_id is not None:
             chat.client.external_id = client_data.external_id
         if client_data.lead_form_data is not None:
