@@ -23,9 +23,9 @@ class AIAgentInChatCollection(AssetCollection[ChattyAIAgentInChat, ChattyAIAgent
             preview_type=ChattyAIAgentInChat  # No separate preview type needed
         )
 
-    def get_by_chat_id(self, chat_id: str) -> Optional[ChattyAIAgentInChat]:
+    async def get_by_chat_id(self, chat_id: str) -> Optional[ChattyAIAgentInChat]:
         """Get AI agent state by chat ID, or None if not found"""
-        doc = self.collection.find_one({"chat_id": chat_id, "deleted_at": None}, projection={"chain_of_thoughts": 0})
+        doc = await self.async_collection.find_one({"chat_id": chat_id, "deleted_at": None})
         if not doc:
             return None
         return self.create_instance(doc)
